# carbon-icons

[![Build Status](https://travis-ci.org/carbon-design-system/carbon-icons.svg?branch=master)](https://travis-ci.org/carbon-design-system/carbon-icons)

> Icons for the Carbon Design System

## Getting Started

Run the following command using [npm](https://www.npmjs.com/):

```bash
npm install -S carbon-icons
```

If you prefer [Yarn](https://yarnpkg.com/en/), use the following command instead:

```bash
yarn add carbon-icons
```

## :books: Docs

- [Usage](https://github.com/carbon-design-system/carbon-icons/blob/master/docs/usage.md)
- [Contributing](https://github.com/carbon-design-system/carbon-icons/blob/master/.github/CONTRIBUTING.md)
- [Migration Guides](https://github.com/carbon-design-system/carbon-icons/tree/master/docs/migration-guides)
  - [v3](https://github.com/carbon-design-system/carbon-icons/tree/master/docs/migration-guides/migration-v3.md)
  - [v4](https://github.com/carbon-design-system/carbon-icons/tree/master/docs/migration-guides/migration-v4.md)
  - [v5](https://github.com/carbon-design-system/carbon-icons/tree/master/docs/migration-guides/migration-v5.md)
  - [v6](https://github.com/carbon-design-system/carbon-icons/tree/master/docs/migration-guides/migration-v6.md)
  - [v7](https://github.com/carbon-design-system/carbon-icons/tree/master/docs/migration-guides/migration-v7.md)

## Links

- [CDN - Unpkg](https://unpkg.com/carbon-icons/dist/)
- [Carbon Design System - Iconography](http://carbondesignsystem.com/style/iconography/library)
